@@ -1228,17 +1228,13 @@ StringXNumber MeshOptions_Number[] = {
     "Depth start" },
   { F|O, "RecombinationTestNoGreedyStrat" , opt_mesh_recombination_no_greedy_strat , 0 ,
     "No greedy (global) strategies" },
-  { F|O, "RemeshAlgorithm" , opt_mesh_remesh_algo , 0 ,
-    "Remeshing algorithm (0=no split, 1=automatic, 2=automatic only with metis)" },
-  { F|O, "RemeshParametrization" , opt_mesh_remesh_param , 4 ,
-    "Remeshing using discrete parametrization (0=harmonic_circle, 1=conformal_spectral, "
-    "2=rbf, 3=harmonic_plane, 4=convex_circle, 5=convex_plane, 6=harmonic square, "
-    "7=conformal_fe" },
   { F|O, "RefineSteps" , opt_mesh_refine_steps , 10 ,
     "Number of refinement steps in the MeshAdapt-based 2D algorithms" },
+  { F|O, "Renumber" , opt_mesh_renumber , 1 ,
+    "Renumber nodes and elements in a continuous sequence after mesh generation" },
 
   { F,   "SaveAll" , opt_mesh_save_all , 0. ,
-    "Ignore Physical definitions and save all elements" },
+    "Save all elements, even if they don't belong to physical groups" },
   { F|O, "SaveElementTagType" , opt_mesh_save_element_tag_type , 1. ,
     "Type of the element tag saved in mesh formats that don't support saving "
     "physical or partition ids (1=elementary, 2=physical, 3=partition)" },
