@@ -1,15 +1,13 @@
-// Gmsh - Copyright (C) 1997-2014 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _GEDGE_H_
 #define _GEDGE_H_
 
-#include <list>
 #include <string>
 #include <vector>
-#include <set>
 #include <stdio.h>
 #include "GmshMessage.h"
 #include "GEntity.h"
@@ -21,35 +19,55 @@
 class MElement;
 class MLine;
 class ExtrudeParams;
-class GEdgeCompound;
+class closestPointFinder;
 
 // A model edge.
 class GEdge : public GEntity {
- private:
+private:
   double _length;
   bool _tooSmall;
+  closestPointFinder *_cp;
 
- protected:
+protected:
   GVertex *v0, *v1;
-  // FIXME: normals need to be mutable at the moment, because thay can
-  // be created in const member functions
-  mutable std::map<MVertex*, SVector3, std::less<MVertex*> > _normals;
-  GEdgeCompound *compound; // this model edge belongs to a compound
-  std::list<GFace *> l_faces;
-  // for specific solid modelers that need to re-do the internal curve
-  // if a topological change ending points is done (gluing)
-  virtual void replaceEndingPointsInternals(GVertex *, GVertex *) {}
+  std::vector<GFace *> l_faces;
 
- public:
+public:
+  // same or opposite direction to the master
+  int masterOrientation;
+
+  std::vector<MLine *> lines;
+
+  // when a compound of edges is created, both meshes should be kept alive this
+  // is due to Gmsh's flow and it only applies to model edges
+  GEdge *compound_edge;
+
+public:
   GEdge(GModel *model, int tag, GVertex *_v0, GVertex *_v1);
+  GEdge(GModel *model, int tag);
   virtual ~GEdge();
 
   // delete mesh data
-  virtual void deleteMesh();
+  virtual void deleteMesh(bool onlyDeleteElements = false);
 
   // get the start/end vertices of the edge
-  GVertex *getBeginVertex() const { return v0; }
-  GVertex *getEndVertex() const { return v1; }
+  void setBeginVertex(GVertex *gv) { v0 = gv; }
+  void setEndVertex(GVertex *gv) { v1 = gv; }
+  virtual GVertex *getBeginVertex() const { return v0; }
+  virtual GVertex *getEndVertex() const { return v1; }
+  void setVertex(GVertex *const f, const int orientation)
+  {
+    if(orientation > 0)
+      v0 = f;
+    else if(orientation < 0)
+      v1 = f;
+  }
+
+  // specify mesh master with transformation, deduce edgeCounterparts
+  void setMeshMaster(GEdge *master, const std::vector<double> &);
+
+  // specify mesh master and edgeCounterparts, deduce transformation
+  void setMeshMaster(GEdge *master, int sign);
 
   void reverse();
 
@@ -60,23 +78,32 @@ class GEdge : public GEntity {
   // get the dimension of the edge (1)
   virtual int dim() const { return 1; }
 
+  // returns the parent entity for partitioned entities
+  virtual GEntity *getParentEntity() { return 0; }
+
+  // get the list of vertices
+  virtual std::vector<GVertex *> vertices() const;
+
   // set the visibility flag
-  virtual void setVisibility(char val, bool recursive=false);
+  virtual void setVisibility(char val, bool recursive = false);
+
+  // set color
+  virtual void setColor(unsigned int val, bool recursive = false);
 
   // true if the edge is a seam for the given face.
   virtual bool isSeam(const GFace *face) const { return false; }
 
   // get the bounding box
-  virtual SBoundingBox3d bounds() const;
+  virtual SBoundingBox3d bounds(bool fast = false) const;
 
   // get the oriented bounding box
   virtual SOrientedBoundingBox getOBB();
 
-  // regions that are boundedby this entity
-  virtual std::list<GRegion*> regions() const;
+  // regions that are bounded by this entity
+  virtual std::list<GRegion *> regions() const;
 
   // faces that this entity bounds
-  virtual std::list<GFace*> faces() const { return l_faces; }
+  virtual std::vector<GFace *> faces() const { return l_faces; }
 
   // get the point for the given parameter location
   virtual GPoint point(double p) const = 0;
@@ -111,29 +138,32 @@ class GEdge : public GEntity {
   virtual int minimumDrawSegments() const { return 1; }
 
   // return a type-specific additional information string
-  virtual std::string getAdditionalInfoString();
+  virtual std::string getAdditionalInfoString(bool multline = false);
 
   // export in GEO format
   virtual void writeGEO(FILE *fp);
 
-  // tell if the edge is a 3D edge (in opposition with a trimmed curve on a surface)
+  // tell if the edge is a 3D edge (in opposition with a trimmed curve on a
+  // surface)
   virtual bool is3D() const { return true; }
 
   // get/set/compute the length of the model edge
-  inline double length() const { return _length; }
-  inline void setLength(const double l) { _length = l; }
+  double length() const { return _length; }
+  void setLength(const double l) { _length = l; }
   double length(const double &u0, const double &u1, const int nbQuadPoints = 4);
 
   // get the prescribed mesh size on the edge
-  virtual double prescribedMeshSizeAtVertex() const { return meshAttributes.meshSize; }
+  virtual double prescribedMeshSizeAtVertex() const
+  {
+    return meshAttributes.meshSize;
+  }
 
   // true if start == end and no more than 2 segments
-  void setTooSmall(bool b) { _tooSmall = b; }
+  void setTooSmall(bool const b) { _tooSmall = b; }
   bool isMeshDegenerated() const
   {
-    if (_tooSmall)
-      Msg::Debug("degenerated mesh on edge %d: too small", tag());
-    if (v0 == v1 && mesh_vertices.size() < 2)
+    if(_tooSmall) Msg::Debug("degenerated mesh on edge %d: too small", tag());
+    if(v0 == v1 && mesh_vertices.size() < 2)
       Msg::Debug("degenerated mesh on edge %d: %d mesh vertices", tag(),
                  (int)mesh_vertices.size());
     return _tooSmall || (v0 == v1 && mesh_vertices.size() < 2);
@@ -143,7 +173,8 @@ class GEdge : public GEntity {
   int getNumElementTypes() const { return 1; }
 
   // get total/by-type number of elements in the mesh
-  unsigned int getNumMeshElements();
+  size_type getNumMeshElements() const { return lines.size(); }
+  unsigned int getNumMeshElementsByType(const int familyType) const;
   unsigned int getNumMeshParentElements();
   void getNumMeshElements(unsigned *const c) const;
 
@@ -151,7 +182,10 @@ class GEdge : public GEntity {
   MElement *const *getStartElementType(int type) const;
 
   // get the element at the given index
-  MElement *getMeshElement(unsigned int index);
+  MElement *getMeshElement(unsigned int index) const;
+  // get the element at the given index for a given familyType
+  MElement *getMeshElementByType(const int familyType,
+                                 const unsigned int index) const;
 
   // reset the mesh attributes to default values
   virtual void resetMeshAttributes();
@@ -159,12 +193,10 @@ class GEdge : public GEntity {
   // true if entity is periodic in the "dim" direction.
   virtual bool periodic(int dim) const { return v0 == v1; }
 
-  std::map<MVertex*, SVector3, std::less<MVertex*> > &getNormals() { return _normals; }
-
   // get bounds of parametric coordinate
   virtual Range<double> parBounds(int i) const = 0;
-  inline double getLowerBound() const{ return parBounds(0).low();};
-  inline double getUpperBound() const{ return parBounds(0).high();};
+  double getLowerBound() const { return parBounds(0).low(); };
+  double getUpperBound() const { return parBounds(0).high(); };
 
   // return the point on the face closest to the given point
   virtual GPoint closestPoint(const SPoint3 &queryPoint, double &param) const;
@@ -172,17 +204,12 @@ class GEdge : public GEntity {
   // return the parmater location on the edge given a point in space
   // that is on the edge
   virtual double parFromPoint(const SPoint3 &P) const;
+  virtual bool refineProjection(const SVector3 &Q, double &u, int MaxIter,
+                                double relax, double tol, double &err) const;
 
   // compute the parameter U from a point XYZ
-  virtual bool XYZToU(const double X, const double Y, const double Z,
-                      double &U, const double relax=0.5) const;
-
-  // compound
-  void setCompound(GEdgeCompound *gec) { compound = gec; }
-  GEdgeCompound *getCompound() const { return compound; }
-
-  // gluing
-  void replaceEndingPoints(GVertex *, GVertex *);
+  virtual bool XYZToU(const double X, const double Y, const double Z, double &U,
+                      const double relax = 1, bool first = true) const;
 
   // relocate mesh vertices using parametric coordinates
   void relocateMeshVertices();
@@ -198,17 +225,22 @@ class GEdge : public GEntity {
     ExtrudeParams *extrude;
     // reverse mesh orientation
     bool reverseMesh;
-  } meshAttributes ;
+  } meshAttributes;
 
   struct {
     mutable GEntity::MeshGenerationStatus status;
   } meshStatistics;
 
-  std::vector<MLine*> lines;
+  void addLine(MLine *line) { lines.push_back(line); }
+  void addElement(int type, MElement *e);
+  void removeElement(int type, MElement *e);
 
-  void addLine(MLine *line){ lines.push_back(line); }
+  virtual void discretize(double tol, std::vector<SPoint3> &dpts,
+                          std::vector<double> &ts);
+  SPoint3 closestPoint(SPoint3 &p, double tolerance);
+  virtual void mesh(bool verbose);
 
-  bool computeDistanceFromMeshToGeometry (double &d2, double &dmax);
+  virtual bool reorder(const int elementType, const std::vector<int> &ordering);
 };
 
 #endif
