@@ -671,11 +671,15 @@ int GModel::_readMSH2(const std::string &name)
 }
 
 template <class T>
-static void writeElementMSH(FILE *fp, GModel *model, T *ele, bool saveAll,
-                            double version, bool binary, int &num,
+static void writeElementMSH(FILE *fp, GModel *model, GEntity *ge, T *ele,
+                            bool saveAll, double version, bool binary, int &num,
                             int elementary, std::vector<int> &physicals,
                             int parentNum = 0, int dom1Num = 0, int dom2Num = 0)
 {
+  if(CTX::instance()->mesh.partitionOldStyleMsh2 && ge->getParentEntity()
+     && ge->getParentEntity()->dim() > ge->dim())
+    return; // ignore partition boundaries
+
   std::vector<short> ghosts;
   if(model->getGhostCells().size()) {
     std::pair<std::multimap<MElement *, short>::iterator,
@@ -705,11 +709,16 @@ static void writeElementMSH(FILE *fp, GModel *model, T *ele, bool saveAll,
 }
 
 template <class T>
-static void writeElementsMSH(FILE *fp, GModel *model, std::vector<T *> &ele,
+static void writeElementsMSH(FILE *fp, GModel *model, GEntity *ge,
+                             std::vector<T *> &ele,
                              bool saveAll, int saveSinglePartition,
                              double version, bool binary, int &num,
                              int elementary, std::vector<int> &physicals)
 {
+  if(CTX::instance()->mesh.partitionOldStyleMsh2 && ge->getParentEntity()
+     && ge->getParentEntity()->dim() > ge->dim())
+    return; // ignore partition boundaries
+
   // Hack to save each partition as a separate physical entity
   if(saveSinglePartition < 0) {
     if(ele.empty()) return;
@@ -728,7 +737,7 @@ static void writeElementsMSH(FILE *fp, GModel *model, std::vector<T *> &ele,
         newPhysicals.push_back((maxPhysical - elementary) * offset);
       }
       ele[i]->setPartition(0);
-      writeElementMSH(fp, model, ele[i], saveAll, version, binary, num,
+      writeElementMSH(fp, model, ge, ele[i], saveAll, version, binary, num,
                       newElementary, newPhysicals);
     }
     return;
@@ -741,13 +750,17 @@ static void writeElementsMSH(FILE *fp, GModel *model, std::vector<T *> &ele,
     int parentNum = 0;
     MElement *parent = ele[i]->getParent();
     if(parent) parentNum = model->getMeshElementIndex(parent);
-    writeElementMSH(fp, model, ele[i], saveAll, version, binary, num,
+    writeElementMSH(fp, model, ge, ele[i], saveAll, version, binary, num,
                     elementary, physicals, parentNum);
   }
 }
 
 static int getNumElementsMSH(GEntity *ge, bool saveAll, int saveSinglePartition)
 {
+  if(CTX::instance()->mesh.partitionOldStyleMsh2 && ge->getParentEntity()
+     && ge->getParentEntity()->dim() > ge->dim())
+    return 0; // ignore partition boundaries
+
   int n = 0, p = saveAll ? 1 : ge->physicals.size();
 
   if(saveSinglePartition < 0 && ge->tag() < 0) p = 1; // partition boundary
@@ -819,8 +832,8 @@ static int getNumElementsMSH(GModel *m, bool saveAll, int saveSinglePartition)
 
 static int _getElementary(GEntity *ge)
 {
-  if(CTX::instance()->mesh.partitionOldStyleMsh2 && ge->getParentEntity() &&
-     ge->getParentEntity()->dim() == ge->dim()) {
+  if(CTX::instance()->mesh.partitionOldStyleMsh2 && ge->getParentEntity()
+     && ge->getParentEntity()->dim() == ge->dim()) {
     // hack for backward compatibility of partitioned meshes in MSH2 format: use
     // elementary tag of parent entity if they are of the same dimension
     // (i.e. if they are not partition boundaries)
@@ -834,10 +847,10 @@ static int _getElementary(GEntity *ge)
 int GModel::_writeMSH2(const std::string &name, double version, bool binary,
                        bool saveAll, bool saveParametric, double scalingFactor,
                        int elementStartNum, int saveSinglePartition,
-                       bool multipleView, bool renumberVertices)
+                       bool append, bool renumberVertices)
 {
   FILE *fp;
-  if(multipleView)
+  if(append)
     fp = Fopen(name.c_str(), binary ? "ab" : "a");
   else
     fp = Fopen(name.c_str(), binary ? "wb" : "w");
@@ -929,103 +942,103 @@ int GModel::_writeMSH2(const std::string &name, double version, bool binary,
     for(viter it = firstVertex(); it != lastVertex(); ++it) {
       for(unsigned int i = 0; i < (*it)->points.size(); i++)
         if((*it)->points[i]->ownsParent())
-          writeElementMSH(fp, this, (*it)->points[i]->getParent(), saveAll,
+          writeElementMSH(fp, this, *it, (*it)->points[i]->getParent(), saveAll,
                           version, binary, num, _getElementary(*it),
                           (*it)->physicals);
     }
     for(eiter it = firstEdge(); it != lastEdge(); ++it) {
       for(unsigned int i = 0; i < (*it)->lines.size(); i++)
         if((*it)->lines[i]->ownsParent())
-          writeElementMSH(fp, this, (*it)->lines[i]->getParent(), saveAll,
+          writeElementMSH(fp, this, *it, (*it)->lines[i]->getParent(), saveAll,
                           version, binary, num, _getElementary(*it),
                           (*it)->physicals);
     }
     for(fiter it = firstFace(); it != lastFace(); ++it) {
       for(unsigned int i = 0; i < (*it)->triangles.size(); i++)
         if((*it)->triangles[i]->ownsParent())
-          writeElementMSH(fp, this, (*it)->triangles[i]->getParent(), saveAll,
+          writeElementMSH(fp, this, *it, (*it)->triangles[i]->getParent(), saveAll,
                           version, binary, num, _getElementary(*it),
                           (*it)->physicals);
     }
     for(riter it = firstRegion(); it != lastRegion(); ++it) {
       for(unsigned int i = 0; i < (*it)->tetrahedra.size(); i++)
         if((*it)->tetrahedra[i]->ownsParent())
-          writeElementMSH(fp, this, (*it)->tetrahedra[i]->getParent(), saveAll,
+          writeElementMSH(fp, this, *it, (*it)->tetrahedra[i]->getParent(), saveAll,
                           version, binary, num, _getElementary(*it),
                           (*it)->physicals);
     }
     for(fiter it = firstFace(); it != lastFace(); ++it) {
       for(unsigned int i = 0; i < (*it)->polygons.size(); i++)
         if((*it)->polygons[i]->ownsParent())
-          writeElementMSH(fp, this, (*it)->polygons[i]->getParent(), saveAll,
+          writeElementMSH(fp, this, *it, (*it)->polygons[i]->getParent(), saveAll,
                           version, binary, num, _getElementary(*it),
                           (*it)->physicals);
     }
     for(riter it = firstRegion(); it != lastRegion(); ++it) {
       for(unsigned int i = 0; i < (*it)->polyhedra.size(); i++)
         if((*it)->polyhedra[i]->ownsParent())
-          writeElementMSH(fp, this, (*it)->polyhedra[i]->getParent(), saveAll,
+          writeElementMSH(fp, this, *it, (*it)->polyhedra[i]->getParent(), saveAll,
                           version, binary, num, _getElementary(*it),
                           (*it)->physicals);
     }
   }
   // points
   for(viter it = firstVertex(); it != lastVertex(); ++it) {
-    writeElementsMSH(fp, this, (*it)->points, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->points, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // lines
   for(eiter it = firstEdge(); it != lastEdge(); ++it) {
-    writeElementsMSH(fp, this, (*it)->lines, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->lines, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // triangles
   for(fiter it = firstFace(); it != lastFace(); ++it) {
-    writeElementsMSH(fp, this, (*it)->triangles, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->triangles, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // quads
   for(fiter it = firstFace(); it != lastFace(); ++it) {
-    writeElementsMSH(fp, this, (*it)->quadrangles, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->quadrangles, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // polygons
   for(fiter it = firstFace(); it != lastFace(); it++) {
-    writeElementsMSH(fp, this, (*it)->polygons, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->polygons, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // tets
   for(riter it = firstRegion(); it != lastRegion(); ++it) {
-    writeElementsMSH(fp, this, (*it)->tetrahedra, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->tetrahedra, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // hexas
   for(riter it = firstRegion(); it != lastRegion(); ++it) {
-    writeElementsMSH(fp, this, (*it)->hexahedra, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->hexahedra, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // prisms
   for(riter it = firstRegion(); it != lastRegion(); ++it) {
-    writeElementsMSH(fp, this, (*it)->prisms, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->prisms, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // pyramids
   for(riter it = firstRegion(); it != lastRegion(); ++it) {
-    writeElementsMSH(fp, this, (*it)->pyramids, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->pyramids, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
   // polyhedra
   for(riter it = firstRegion(); it != lastRegion(); ++it) {
-    writeElementsMSH(fp, this, (*it)->polyhedra, saveAll, saveSinglePartition,
+    writeElementsMSH(fp, this, *it, (*it)->polyhedra, saveAll, saveSinglePartition,
                      version, binary, num, _getElementary(*it),
                      (*it)->physicals);
   }
@@ -1034,7 +1047,7 @@ int GModel::_writeMSH2(const std::string &name, double version, bool binary,
     for(unsigned int i = 0; i < (*it)->triangles.size(); i++) {
       MTriangle *t = (*it)->triangles[i];
       if(t->getDomain(0))
-        writeElementMSH(fp, this, t, saveAll, version, binary, num,
+        writeElementMSH(fp, this, *it, t, saveAll, version, binary, num,
                         _getElementary(*it), (*it)->physicals, 0,
                         getMeshElementIndex(t->getDomain(0)),
                         getMeshElementIndex(t->getDomain(1)));
@@ -1042,7 +1055,7 @@ int GModel::_writeMSH2(const std::string &name, double version, bool binary,
     for(unsigned int i = 0; i < (*it)->polygons.size(); i++) {
       MPolygon *p = (*it)->polygons[i];
       if(p->getDomain(0))
-        writeElementMSH(fp, this, p, saveAll, version, binary, num,
+        writeElementMSH(fp, this, *it, p, saveAll, version, binary, num,
                         _getElementary(*it), (*it)->physicals, 0,
                         getMeshElementIndex(p->getDomain(0)),
                         getMeshElementIndex(p->getDomain(1)));
@@ -1053,7 +1066,7 @@ int GModel::_writeMSH2(const std::string &name, double version, bool binary,
     for(unsigned int i = 0; i < (*it)->lines.size(); i++) {
       MLine *l = (*it)->lines[i];
       if(l->getDomain(0))
-        writeElementMSH(fp, this, l, saveAll, version, binary, num,
+        writeElementMSH(fp, this, *it, l, saveAll, version, binary, num,
                         _getElementary(*it), (*it)->physicals, 0,
                         getMeshElementIndex(l->getDomain(0)),
                         getMeshElementIndex(l->getDomain(1)));
