@@ -1,7 +1,7 @@
-// Gmsh - Copyright (C) 1997-2014 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _DISCRETE_REGION_H_
 #define _DISCRETE_REGION_H_
@@ -11,12 +11,15 @@
 #include "MFace.h"
 
 class discreteRegion : public GRegion {
- public:
+public:
   discreteRegion(GModel *model, int num);
   virtual ~discreteRegion() {}
   virtual GeomType geomType() const { return DiscreteVolume; }
-  void setBoundFaces(std::set<int> tagFaces);
+  void setBoundFaces(const std::set<int> &tagFaces);
+  void setBoundFaces(const std::vector<int> &tagFaces,
+                     const std::vector<int> &signFaces);
   void findFaces(std::map<MFace, std::vector<int>, Less_Face> &map_faces);
+  virtual void remesh();
 };
 
 #endif
