@@ -1,22 +1,20 @@
-// Gmsh - Copyright (C) 1997-2014 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _EXTRACT_ELEMENTS_H_
 #define _EXTRACT_ELEMENTS_H_
 
 #include "Plugin.h"
 
-extern "C"
-{
-  GMSH_Plugin *GMSH_RegisterExtractElementsPlugin();
+extern "C" {
+GMSH_Plugin *GMSH_RegisterExtractElementsPlugin();
 }
 
-class GMSH_ExtractElementsPlugin : public GMSH_PostPlugin
-{
- public:
-  GMSH_ExtractElementsPlugin(){}
+class GMSH_ExtractElementsPlugin : public GMSH_PostPlugin {
+public:
+  GMSH_ExtractElementsPlugin() {}
   std::string getName() const { return "ExtractElements"; }
   std::string getShortHelp() const
   {
@@ -24,7 +22,7 @@ class GMSH_ExtractElementsPlugin : public GMSH_PostPlugin
   }
   std::string getHelp() const;
   int getNbOptions() const;
-  StringXNumber* getOption(int iopt);  
+  StringXNumber *getOption(int iopt);
   PView *execute(PView *);
 };
 
