@@ -1,24 +1,23 @@
-// Gmsh - Copyright (C) 1997-2014 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@geuz.org>.
+// bugs and problems to the public mailing list <gmsh@onelab.info>.
 
 #ifndef _PARTICLES_H_
-#define _PARTICLES_H
+#define _PARTICLES_H_
 
 #include "Plugin.h"
 
-extern "C"
-{
-  GMSH_Plugin *GMSH_RegisterParticlesPlugin ();
+extern "C" {
+GMSH_Plugin *GMSH_RegisterParticlesPlugin();
 }
 
-class GMSH_ParticlesPlugin : public GMSH_PostPlugin
-{
+class GMSH_ParticlesPlugin : public GMSH_PostPlugin {
   static double callback(int num, int action, double value, double *opt,
                          double step, double min, double max);
- public:
-  GMSH_ParticlesPlugin(){}
+
+public:
+  GMSH_ParticlesPlugin() {}
   std::string getName() const { return "Particles"; }
   std::string getShortHelp() const
   {
@@ -26,7 +25,7 @@ class GMSH_ParticlesPlugin : public GMSH_PostPlugin
   }
   std::string getHelp() const;
   int getNbOptions() const;
-  StringXNumber *getOption(int iopt);  
+  StringXNumber *getOption(int iopt);
   PView *execute(PView *);
 
   static int getNbU();
