@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2017 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
 // bugs and problems to the public mailing list <gmsh@onelab.info>.
@@ -8,23 +8,18 @@
 
 #include "Plugin.h"
 
-extern "C"
-{
-  GMSH_Plugin *GMSH_RegisterSmoothPlugin();
+extern "C" {
+GMSH_Plugin *GMSH_RegisterSmoothPlugin();
 }
 
-class GMSH_SmoothPlugin : public GMSH_PostPlugin
-{
- public:
-  GMSH_SmoothPlugin(){}
+class GMSH_SmoothPlugin : public GMSH_PostPlugin {
+public:
+  GMSH_SmoothPlugin() {}
   std::string getName() const { return "Smooth"; }
-  std::string getShortHelp() const
-  {
-    return "Apply nodal smoothing";
-  }
+  std::string getShortHelp() const { return "Apply nodal smoothing"; }
   std::string getHelp() const;
   int getNbOptions() const;
-  StringXNumber *getOption(int iopt);  
+  StringXNumber *getOption(int iopt);
   PView *execute(PView *);
 };
 
